@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.42.2.3 2003/03/03 18:30:41 joern Exp $
+# $Id: Config.pm,v 1.42.2.4 2003/03/28 20:36:13 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -76,8 +76,7 @@ my %CONFIG_PARAMETER = (
 		value => 'mplayer <dvd://%t -aid %(%a+128) -chapter %c -dvdangle %m>',
 		presets => [
 			'mplayer <dvd://%t -aid %(%a+128) -chapter %c -dvdangle %m>',
-			'xine -a %a -p <dvdnav://%d:%t.%c>',
-			'xine -a %a -p <d4d://i%tt0c%(%c-1)t%(%c-1)>',
+			'xine -a %a -p <dvd://%t.%c>',
 		],
 	},
 	play_file_command => {
@@ -534,7 +533,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.42.2.3 2003/03/03 18:30:41 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.42.2.4 2003/03/28 20:36:13 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
